@@ -175,14 +175,14 @@ filter_coastal <- function(flines) {
   }
 }
 
-
+# TODO: document as calling hydroloom
 #' Get tocomid
 #' @description Given flowlines with fromnode and tonode attributes,
 #' will return a toid attribute that is the result of joining
 #' tonode and fromnode attributes. In the case that a terminalpa
 #' attribute is included, the join is executed by terminalpa group.
 #' This is done grouped by terminalpathID because duplicate node
-#' ids have been encountered accross basins in some datasets. If
+#' ids have been encountered across basins in some datasets. If
 #' `remove_coastal` is `TRUE` (the default) either ftype or fcode are
 #' required.
 #' @param x data.frame with comid, tonode, fromnode, and (optionally)
@@ -212,50 +212,35 @@ get_tocomid <- function(x, return_dendritic = TRUE, missing = 0,
 
   x <- check_names(x, "get_tocomid", tolower = TRUE)
 
-  hy_g <- NULL
-  if(add && inherits(x, "sf")) {
-    # need to keep geometry for later
-    hy_g <- select(x, .data$comid)
-  }
+  hy_g <- get_hyg(x, add, "comid")
 
   x <- drop_geometry(x)
 
   if(remove_coastal)
     x <- filter_coastal(x)
 
-  joiner_fun <- function(x) {
-    left_join(x, select(x,
-                        tocomid = .data$comid,
-                        .data$fromnode),
-              by = c("tonode" = "fromnode"))
-  }
-
-  order <- data.frame(comid = x$comid)
-
-  if(return_dendritic) {
-    if(!"divergence" %in% names(x)) {
-      stop("To remove non dendritic paths, a divergence attribute is required.")
-    }
-
-    x[["fromnode"]][which(x$divergence == 2)] <- NA
-
-  }
+  x <- rename(x, id = "comid")
 
   if("terminalpa" %in% names(x)) {
 
+    order <- data.frame(id = x$id)
+
     x <- group_split(group_by(x, .data$terminalpa))
-    x <- bind_rows(lapply(x, joiner_fun))
+    x <- bind_rows(lapply(x, add_toids, return_dendritic = return_dendritic))
+
+    x <- left_join(order, x, by = c("id"))
 
   } else {
 
-    x <- joiner_fun(x)
+    x <- add_toids(x, return_dendritic)
 
   }
 
-  x <- left_join(order, x, by = c("comid"))
+  x <- rename(x, comid = "id", tocomid = "toid")
 
-  if(!is.na(missing)) {
-    x[["tocomid"]] <- tidyr::replace_na(x[["tocomid"]], 0)
+  if(!is.na(missing) & missing != 0) {
+    repl <- x[["tocomid"]] == 0
+    x[["tocomid"]][repl] <- rep(missing, sum(repl))
   }
 
   if(add) {
@@ -269,7 +254,7 @@ get_tocomid <- function(x, return_dendritic = TRUE, missing = 0,
 
   } else {
 
-    as.data.frame(select(x, .data$comid, .data$tocomid))
+    as.data.frame(select(x, "comid", "tocomid"))
 
   }
 }
