@@ -1,4 +1,21 @@
+test_that("basic two flowline network", {
 
+  net_new <- structure(list(comid = c(6170348, 6170858),
+                            tocomid = c(0, 6170348),
+                            gnis_id = c(" ", " "),
+                            areasqkm = c(0.1089, 0),
+                            lengthkm = c(0.224, 0.152),
+                            levelpathi = c(150042200, 150042200)),
+                       class = "data.frame",
+                       row.names = c(NA, -2L))
+
+  expect_warning(net_new <-
+    add_plus_network_attributes(
+      dplyr::rename(net_new, nameID = gnis_id), status = FALSE))
+
+
+  expect_equal(nrow(net_new), 2)
+})
 
 test_that("example", {
   skip_on_cran()
